import type { Hash } from "@siteimprove/alfa-hash";
import { type Parser as CSSParser } from "../../syntax/index.js";
import { Position } from "../position/index.js";
import type { PartiallyResolvable, Resolvable } from "../resolvable.js";
import { Value } from "../value.js";
import { BasicShape } from "./basic-shape.js";
import { Radius } from "./radius.js";
/**
 * {@link https://drafts.csswg.org/css-shapes/#funcdef-circle}
 *
 * @public
 */
export declare class Circle<R extends Radius = Radius, P extends Position = Position> extends BasicShape<"circle", Value.HasCalculation<[R, P]>> implements Resolvable<Circle.Canonical, Circle.Resolver>, PartiallyResolvable<Circle.PartiallyResolved, Circle.PartialResolver> {
    static of<R extends Radius, P extends Position>(radius: R, center: P): Circle<R, P>;
    private readonly _radius;
    private readonly _center;
    private constructor();
    get radius(): R;
    get center(): P;
    resolve(resolver: Circle.Resolver): Circle.Canonical;
    partiallyResolve(resolver: Circle.PartialResolver): Circle.PartiallyResolved;
    equals(value: Circle): boolean;
    equals(value: unknown): value is this;
    hash(hash: Hash): void;
    toJSON(): Circle.JSON;
    toString(): string;
}
/**
 * @public
 */
export declare namespace Circle {
    type Canonical = Circle<Radius.Canonical, Position.Canonical>;
    type PartiallyResolved = Circle<Radius.PartiallyResolved, Position.PartiallyResolved>;
    interface JSON extends BasicShape.JSON<"circle"> {
        radius: Radius.JSON;
        center: Position.JSON;
    }
    type Resolver = Radius.Resolver & Position.Resolver;
    type PartialResolver = Radius.PartialResolver & Position.PartialResolver;
    function isCircle(value: unknown): value is Circle;
    const parse: CSSParser<Circle>;
}
//# sourceMappingURL=circle.d.ts.map